@@ -324,6 +324,40 @@ DECLARE_REFLECTION_STRUCT(BugReport);
       ":type: bool");                                                                              \
   CONFIG_SETTING_VAL(public, bool, bool, TextureViewer_PerTexYFlip, false)                         \
                                                                                                    \
+  DOCUMENT(                                                                                        \
+      "List of Qt keycodes for mesh viewer key bindings. Can be empty if no keys are configured "  \
+      "which will revert to default behaviour of physical WASD (independent of local keyboard "    \
+      "layout)."                                                                                   \
+      "\n"                                                                                         \
+      "Defaults to an empty list."                                                                 \
+      ""                                                                                           \
+      ":type: List[int]");                                                                         \
+  CONFIG_SETTING(public, QVariantList, rdcarray<uint32_t>, MeshViewer_KeySettings)                 \
+                                                                                                   \
+  DOCUMENT(                                                                                        \
+      "The Qt modifier code for the mesh viewer 'speed' modifier."                                 \
+      "\n"                                                                                         \
+      "Defaults to ``-1`` which means Shift."                                                      \
+      ""                                                                                           \
+      ":type: int");                                                                               \
+  CONFIG_SETTING_VAL(public, int, int, MeshViewer_SpeedModifier, -1)                               \
+                                                                                                   \
+  DOCUMENT(                                                                                        \
+      "The near plane used in the mesh viewers display."                                           \
+      "\n"                                                                                         \
+      "Defaults to ``0.1``."                                                                       \
+      ""                                                                                           \
+      ":type: float");                                                                             \
+  CONFIG_SETTING_VAL(public, float, float, MeshViewer_CameraNear, 0.1f)                            \
+                                                                                                   \
+  DOCUMENT(                                                                                        \
+      "The far plane used in the mesh viewers display."                                            \
+      "\n"                                                                                         \
+      "Defaults to ``100000.0``."                                                                  \
+      ""                                                                                           \
+      ":type: float");                                                                             \
+  CONFIG_SETTING_VAL(public, float, float, MeshViewer_CameraFar, 100000.0f)                        \
+                                                                                                   \
   DOCUMENT(                                                                                        \
       "List of the directories containing custom shader files for the Texture Viewer.\n"           \
       "\n:"                                                                                        \
@@ -662,7 +696,17 @@ DECLARE_REFLECTION_STRUCT(BugReport);
   CONFIG_SETTING(public, QVariantList, rdcarray<rdcstr>, AlwaysLoad_Extensions)                    \
                                                                                                    \
   DOCUMENT("");                                                                                    \
-  CONFIG_SETTING(private, QVariantList, rdcarray<RemoteHost>, RemoteHostList)
+  CONFIG_SETTING(private, QVariantList, rdcarray<RemoteHost>, RemoteHostList)                      \
+                                                                                                   \
+  DOCUMENT("");                                                                                    \
+  DOCUMENT(                                                                                        \
+      "``False`` if :class:`ResourceUsage` should combine resource usage across marker "           \
+      "boundaries.\n"                                                                              \
+      "\n:"                                                                                        \
+      "Defaults to ``False``."                                                                     \
+      ""                                                                                           \
+      ":type: bool");                                                                              \
+  CONFIG_SETTING_VAL(public, bool, bool, ResourceUsage_SplitByMarker, false)
 
 DOCUMENT(R"(The formatting mode used when displaying fields marked as Offsets or Sizes.
 
