@@ -304,9 +304,9 @@ public:
             if(mod.unboundPS)
             {
               if(!m_IsDepth)
-                return tr("No Pixel\nShader\nBound\n\n");
+                return tr("No Pixel\nShader\nOutput\n\n");
               else
-                return tr("No Pixel Shader Bound\n\n") + modString(mod.shaderOut);
+                return tr("No Pixel Shader Output\n\n") + modString(mod.shaderOut);
             }
             if(mod.directShaderWrite)
               return tr("Tex Before\n\n") + modString(mod.preMod);
@@ -666,12 +666,13 @@ PixelHistoryView::PixelHistoryView(ICaptureContext &ctx, ResourceId id, QPoint p
     channelStr = lit("Alpha");
 
   QString text;
-  text = tr("Preview colours displayed in visible range %1 - %2 with %3 visible.\n\n")
-             .arg(Formatter::Format(display.rangeMin))
-             .arg(Formatter::Format(display.rangeMax))
-             .arg(channelStr);
+
+  text += tr("Preview colours displayed in visible range %1 - %2 with %3 visible.<br><br>")
+              .arg(Formatter::Format(display.rangeMin))
+              .arg(Formatter::Format(display.rangeMax))
+              .arg(channelStr);
   text +=
-      tr("Double click to jump to an event.\n"
+      tr("Double click to jump to an event.<br>"
          "Right click to debug an event, or hide failed events.");
 
   ui->label->setText(text);
@@ -717,6 +718,16 @@ PixelHistoryView::~PixelHistoryView()
   delete ui;
 }
 
+void PixelHistoryView::SetFailedDebug()
+{
+  QString text = ui->label->text();
+  text = tr("<b>Pixel shader debug failed</b> - most likely this is caused by no write to the "
+            "pixel at the current event.<br>"
+            "Displaying pixel history to find the event which did write.<br><br>") +
+         text;
+  ui->label->setText(text);
+}
+
 void PixelHistoryView::enableTimelineHighlight()
 {
   if(m_Ctx.HasTimelineBar())
@@ -913,6 +924,14 @@ void PixelHistoryView::on_events_customContextMenuRequested(const QPoint &pos)
     debugAction.setEnabled(false);
   }
 
+  const ActionDescription *action = m_Ctx.GetAction(tag.eventId);
+  if(action == NULL ||
+     (action->flags & (ActionFlags::Drawcall | ActionFlags::MeshDispatch)) == ActionFlags::NoFlags)
+  {
+    debugAction.setToolTip(tr("This event has no shader use"));
+    debugAction.setEnabled(false);
+  }
+
   // can't check if the shader supports debugging here because we don't have its details.
 
   QObject::connect(&jumpAction, &QAction::triggered, [this, tag]() { jumpToPrimitive(tag); });
