@@ -38,12 +38,16 @@
   HEADER(gl_texsample)       \
   HEADER(gles_texsample)
 
+#define HLSL_HEADERS(HEADER) HEADER(quadswizzle)
+
 class EmbeddedIncluder : public glslang::TShader::Includer
 {
 #define DECL(header) rdcstr header = GetEmbeddedResource(CONCAT(glsl_, CONCAT(header, _h)));
   GLSL_HEADERS(DECL)
 #undef DECL
 
+  rdcstr quadswizzle = GetEmbeddedResource(hlsl_quadswizzle_hlsl);
+
 public:
   // For the "system" or <>-style includes; search the "system" paths.
   virtual IncludeResult *includeSystem(const char *headerName, const char *includerName,
@@ -55,6 +59,11 @@ public:
     GLSL_HEADERS(GET)
 #undef GET
 
+    if(!strcmp(headerName, "quadswizzle.hlsl"))
+    {
+      return new IncludeResult("quadswizzle.hlsl", quadswizzle.data(), quadswizzle.length(), NULL);
+    }
+
     return NULL;
   }
 
