@@ -547,6 +547,13 @@ enum class ThreadScope : uint32_t
 
 BITMASK_OPERATORS(ThreadScope);
 
+enum class ComputeDerivativeMode : uint8_t
+{
+  None,
+  Linear,
+  Quad,
+};
+
 class Processor
 {
 public:
@@ -567,6 +574,14 @@ public:
       return empty;
     return it->second;
   }
+  const DataType &GetDataType(Id id) const
+  {
+    static DataType empty;
+    auto it = dataTypes.find(id);
+    if(it == dataTypes.end())
+      return empty;
+    return it->second;
+  }
   const Decorations &GetDecorations(Id id) const { return decorations[id]; };
   const rdcarray<uint32_t> &GetSPIRV() const { return m_SPIRV; }
 protected:
